import React, {useState} from 'react';
import { connect } from "react-redux";
import {Link, useLocation} from "react-router-dom";
import {Avatar, Button, Divider, Dropdown, Modal, Nav, Navbar} from "rsuite";
import List from "@rsuite/icons/List";
import * as faDoorOpen from "@fortawesome/free-solid-svg-icons/faDoorOpen";
import * as faUserPlus from "@fortawesome/free-solid-svg-icons/faUserPlus";
import * as faDiscordIcon from "@fortawesome/free-brands-svg-icons/faDiscord";
import * as faVestPatches from "@fortawesome/free-solid-svg-icons/faVestPatches"
import * as faUser from "@fortawesome/free-solid-svg-icons/faUser";
import {Icon} from "@rsuite/icons";
import Login from "./login";
import {useCookies} from "react-cookie";
import {setToken, setUser} from "../redux/actions/User";



const FaSvgIcon = ({ faIcon, ...rest }) => {
    const { width, height, svgPathData } = faIcon;
    return (
        <svg {...rest} viewBox={`0 0 ${width} ${height}`} width="2em" height="2em" fill="currentColor">
            <path d={svgPathData}/>
        </svg>
    );
};

const SiteNavbar = ({token, user, dispatch}) => {
    const location = useLocation();
    const [open, setOpen] = useState(false);
    const [isRegistrationModalVisible, setRegistrationModalVisible] = useState(false);


    const [cookie, ] = useCookies(["token"]);

    if (cookie.token && !token) {
        dispatch(setToken(cookie.token))
    }


    if (token && !user) {
        fetch("/api/v2/me", {headers: {
                "Authorization": `Bearer ${cookie.token}`
            }}).then(res => res.json()).then(r => {
                if (r.username) {
                    dispatch(setUser(r))
                }
        });
    }

    const openModal = () => {
        setOpen(true)
    }
    const handleClose = () => {
        setOpen(false)
    }

    const openRegistrationModal = () => {
        setRegistrationModalVisible(true)
    }

    const routes = [{
        route: "/leaderboard",
        icon: <List />,
        name: "Leaderboard"
    }];

    return (<Navbar >
        <Navbar.Brand>
            <Link style={{textDecoration: "none", color: "black"}} to={"/"}>osu!cstellia</Link>
        </Navbar.Brand>
        <Nav>
                {routes.map((route, index) => <Nav.Item key={index} disabled={location.pathname === route.route} style={{textDecoration: "none", color: route.route === location.pathname ? "#2e9602": "black"}} icon={route.icon}><Link style={{textDecoration: "none", color: route.route === location.pathname ? "#2e9602": "black"}}  to={route.route}>{route.name}</Link></Nav.Item>)}

            <Nav.Item href={"https://discord.gg/aqZtXm8zcG"} icon={<Icon as={FaSvgIcon} faIcon={faDiscordIcon}/>}>Discord</Nav.Item>
        </Nav>
        <Nav pullRight>
            {!user ? (
                    <Dropdown title={"Account"} placement={"bottomEnd"}>
                        <Dropdown.Item key={1} icon={<Icon as={FaSvgIcon} faIcon={faDoorOpen}/>} onClick={openModal}>
                            Login
                        </Dropdown.Item>
                        <Dropdown.Item icon={<Icon as={FaSvgIcon} faIcon={faUserPlus}/>} onClick={openRegistrationModal}>
                            Create account
                        </Dropdown.Item>

                    <Modal key={2} open={isRegistrationModalVisible} onClose={() => setRegistrationModalVisible(false)}>
                        <Modal.Header>
                            <Modal.Title>Account creation</Modal.Title>
                        </Modal.Header>
                        <Modal.Body>
                            To create account you need patch osu!lazer client and register it in game! <br /><br />
                            <Button href={"https://git.kotworks.cyou/DHCPCP/Patcher/-/releases"} color="violet" appearance={"primary"}><Icon as={FaSvgIcon} faIcon={faVestPatches}/> Patcher</Button>
                            <Divider vertical={true}/>
                            <Button href={"https://discord.gg/aqZtXm8zcG"} appearance={"primary"}><Icon as={FaSvgIcon} faIcon={faDiscordIcon}/> Discord</Button>
                        </Modal.Body>
                    </Modal>
                    <Modal open={open} onClose={handleClose}>
                        <Modal.Header>
                            <Modal.Title>Log in</Modal.Title>
                        </Modal.Header>
                        <Modal.Body>
                            <Login open={open} closeModal={handleClose} />
                        </Modal.Body>
                    </Modal>
                    </Dropdown>
            ) : <Dropdown title={<Avatar size={"md"} circle src={`https://a.ppy.sh/${user.id}`} />} placement={"bottomEnd"}>
                <Dropdown.Item panel style={{ padding: 10, width: 160 }}>
                    <p>Signed in as</p>
                    <strong>{user.username}</strong>
                </Dropdown.Item>
                <Dropdown.Item divider />
                <Dropdown.Item icon={<Icon as={FaSvgIcon} faIcon={faUser}/>}><Link to={`/users/${user.id}`} style={{textDecoration: "none", color: "black"}}>Your profile</Link></Dropdown.Item>
            </Dropdown>}
        </Nav>
    </Navbar>);
}

const getCurrentToken = state => {
    return ({
        user: state.User.user,
        token: state.User.token
    })
}

export default connect(getCurrentToken)(SiteNavbar);

