import React, {useState} from 'react';
import { connect } from "react-redux";
import {setToken} from "../redux/actions/User";
import {useCookies} from "react-cookie";
import {Button, ButtonToolbar, Form} from "rsuite";

const getCurrentToken = state => {
    return ({
        token: state.User.token
    })
}

const Login = ({dispatch, token, closeModal}) => {
    const [isLoading, setLoading] = useState(false);
    const [errors, setErrors] = useState({});
    const [, setCookie] = useCookies(["token"]);
    const [username, setUsername] = useState("");
    const [password, setPassword] = useState("");

    const onFinish = async (status, e) => {
        setLoading(true);

        const params = new URLSearchParams();
        params.append("username", username);
        params.append("password", password);

        const response = await fetch("/oauth/token", {
            method: "POST",
            body: params.toString(),
            headers: {
                "content-type": "application/x-www-form-urlencoded"
            }
        });

        let json = await response.json();

        if (!response.ok)
        {
            setErrors({ username: json.message, password: json.message })
            setLoading(false);
            return;
        }

        setLoading(false);
        closeModal();

        setTimeout(() => {
            dispatch(setToken(json.access_token));
            setCookie("token", json.access_token, { path: "/" });
        }, 200)


    }


    return (<div>
        <Form onSubmit={onFinish} disabled={isLoading} formError={errors}>
            <Form.Group controlId={"username"}>
                <Form.ControlLabel>Username</Form.ControlLabel>
                <Form.Control onChange={setUsername} name={"username"} />
            </Form.Group>
            <Form.Group controlId="password">
                <Form.ControlLabel>Password</Form.ControlLabel>
                <Form.Control onChange={setPassword} name="password" type="password" autoComplete="off" />
            </Form.Group>

            <ButtonToolbar>
                <Button appearance="primary" type={"submit"} loading={isLoading}>Submit</Button>
            </ButtonToolbar>
        </Form>

    </div>)
}

export default connect(getCurrentToken)(Login);