
import React, {useEffect, useState} from 'react'
import { connect } from "react-redux";
import {Table, Col, Grid, Row, Avatar} from "rsuite";
import {Link} from "react-router-dom";
import { Pagination } from 'rsuite';
const {HeaderCell, Cell, Column} = Table;


export const CountryFlag = ({ country, size }) => {
    return <Avatar src={`https://osu.gatari.pw/static/images/flags/${country}.png`} style={{ height: size ? size : 40}}  />
}


const UsernameCell = ({ rowData, dataKey, ...props }) => (
    <Cell {...props}>
            <Link to={`/users/${rowData[dataKey]}?search=username`} style={{textDecoration: "none", color: "black"}}>

                {rowData[dataKey]}
            </Link>
    </Cell>
);
const Leaderboard = () => {

    const [filter, setFilter] = useState(false);
    const [data, setData] = useState([]);
    const [isLoading, setLoading] = useState(true);
    const [page, setPage] = useState(0);
    const [total, setTotal] = useState(0);
    const handleChangePage = (dataKey) => {
        setPage(dataKey);
        updateFilter({filter});
    }




    const updateFilter = async (newFilter) => {
        const response = await fetch(`/api/v2/rankings/${newFilter.ruleset}/${newFilter.type}`).then(res => res.json());

        setLoading(false);
        setTotal(response.total);
        setData(response.ranking.map(u =>{
            return {
                global_rank: u.global_rank,
                username: u.user.username,
                country: u.user.country_code,
                pp: u.pp.toFixed(0),
                play_count: u.play_count,
                accuracy: u.hit_accuracy.toFixed(2) + "%"
            }}
        ))
        setFilter(newFilter);

    }

    useEffect(() => {
        updateFilter({ruleset: "osu", type: "performance", page: 0});
    })


    return (<div>
        <Grid fluid>
            <Row>
                <Col xs={1} />
                <Col xs={20}>
                    <Table data={data} loading={isLoading} autoHeight={true} disabledScroll={true}>
                        <Column flexGrow={1} align={"center"}>
                            <HeaderCell>#</HeaderCell>
                            <Cell dataKey={"global_rank"} />
                        </Column>
                        <Column flexGrow={4}>
                            <HeaderCell>Username</HeaderCell>
                            <UsernameCell dataKey={"username"} />
                        </Column>

                        <Column flexGrow={2} >
                            <HeaderCell>PP</HeaderCell>
                            <Cell dataKey="pp" />
                        </Column>

                        <Column flexGrow={2}>
                            <HeaderCell>Accuracy</HeaderCell>
                            <Cell dataKey="accuracy" />
                        </Column>
                        <Column flexGrow={1}>
                            <HeaderCell>Play count</HeaderCell>
                            <Cell dataKey="play_count" />
                        </Column>
                    </Table>
                    <Pagination activePage={page} prev={page > 0} next={page >= total/50} onChangePage={handleChangePage} total={total/50} size={"md"} />
                </Col>
                <Col xs={1} />
            </Row>
        </Grid>
    </div>)
}

export default connect()(Leaderboard);